<?php

namespace Ebuy\Cart\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Ebuy\Cart\Interfaces\CartRepositoryInterface;

class CartPublicController extends BaseController
{
    // use CartWorkflow;

    /**
     * Constructor.
     *
     * @param type \Ebuy\Cart\Interfaces\CartRepositoryInterface $cart
     *
     * @return type
     */
    public function __construct(CartRepositoryInterface $cart)
    {
        $this->repository = $cart;
        parent::__construct();
    }

    /**
     * Show cart's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $carts = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('cart::cart.names'))
            ->view('cart::public.cart.index')
            ->data(compact('carts'))
            ->output();
    }


    /**
     * Show cart.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $cart = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($cart->name . trans('cart::cart.name'))
            ->view('cart::public.cart.show')
            ->data(compact('cart'))
            ->output();
    }

}
